"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.aliMaterialRenderer = void 0;
const tableMdastBuilder_1 = require("../tableMdastBuilder");
const mdast_builder_1 = require("mdast-builder");
const isEnumType = (type) => type.name === 'enum' && Array.isArray(type.value);
/**
 * alibaba materials style renderer
 * @see https://yuque.antfin-inc.com/mo/spec/spec-materials#CZiWi
 * @example
 * ``` md
 * ### Column
 *
 * Form column.
 *
 * #### Props
 *
 * | Name               | Type                                | Default value | Description              |
 * | ------------------ | ----------------------------------- | ------------- | ------------------------ |
 * | prop1              | string                              | "red"         | prop1 description        |
 * | prop2 _(required)_ | number                              |               | prop2 description        |
 * | prop3 _(required)_ | () => void                          |               | prop3 description a \| b |
 * | prop4 _(required)_ | "option1" \| "option2" \| "option3" |               | prop4 description 中文   |
 * ```
 */
exports.aliMaterialRenderer = (componentDoc) => [
    mdast_builder_1.heading(3, mdast_builder_1.text(componentDoc.displayName)),
    mdast_builder_1.text(componentDoc.description),
    mdast_builder_1.heading(4, mdast_builder_1.text('Props')),
    tableMdastBuilder_1.tableMdastBuilder(Object.values(componentDoc.props), [
        {
            title: '参数',
            render: (vo) => vo.required
                ? [mdast_builder_1.text(vo.name), mdast_builder_1.text(' '), mdast_builder_1.emphasis(mdast_builder_1.text('(required)'))]
                : vo.name,
        },
        {
            title: '说明',
            render: (vo) => vo.description,
        },
        {
            title: '类型',
            render: (vo) => mdast_builder_1.inlineCode(isEnumType(vo.type) ? vo.type.raw : vo.type.name),
        },
        {
            title: '可选值',
            render: (vo) => isEnumType(vo.type) ? vo.type.value.map((e) => e.value).join(', ') : '',
        },
        {
            title: '默认值',
            render: (vo) => { var _a; return ((_a = vo.defaultValue) === null || _a === void 0 ? void 0 : _a.value) || ''; },
        },
    ]),
];
//# sourceMappingURL=aliMaterialRenderer.js.map