"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.fluentuiRenderer = void 0;
const tableMdastBuilder_1 = require("../tableMdastBuilder");
const mdast_builder_1 = require("mdast-builder");
/**
 * fluentui style renderer
 * @see https://developer.microsoft.com/en-us/fluentui#/controls/web/button#implementation
 * @example
 * ``` md
 * ### Column
 *
 * Form column.
 *
 * #### Props
 *
 * | Name               | Type                                | Default value | Description              |
 * | ------------------ | ----------------------------------- | ------------- | ------------------------ |
 * | prop1              | string                              | "red"         | prop1 description        |
 * | prop2 _(required)_ | number                              |               | prop2 description        |
 * | prop3 _(required)_ | () => void                          |               | prop3 description a \| b |
 * | prop4 _(required)_ | "option1" \| "option2" \| "option3" |               | prop4 description 中文   |
 * ```
 */
exports.fluentuiRenderer = (componentDoc) => [
    mdast_builder_1.heading(3, mdast_builder_1.text(componentDoc.displayName)),
    mdast_builder_1.text(componentDoc.description),
    mdast_builder_1.heading(4, mdast_builder_1.text('Props')),
    tableMdastBuilder_1.tableMdastBuilder(Object.values(componentDoc.props), [
        {
            title: 'Name',
            render: (vo) => vo.required ? [mdast_builder_1.text(vo.name), mdast_builder_1.text(' '), mdast_builder_1.emphasis(mdast_builder_1.text('(required)'))] : vo.name,
        },
        {
            title: 'Type',
            render: (vo) => vo.type.name,
        },
        {
            title: 'Default value',
            render: (vo) => { var _a; return ((_a = vo.defaultValue) === null || _a === void 0 ? void 0 : _a.value) || ''; },
        },
        {
            title: 'Description',
            render: (vo) => vo.description,
        },
    ]),
];
//# sourceMappingURL=fluentuiRenderer.js.map